==> qt_colored_logger-0.2.0.tar.gz: qt_colored_logger-0.2.0/qt_colored_logger/__init__.py <==
# ##########################   Qt_Colored-logger   ########################### #
# ---------------------------------------------------------------------------- #
#                                                                              #
# Copyright © 2023 Kalynovsky Valentin. All rights reserved.                   #
#                                                                              #
# Licensed under the Apache License, Version 2.0 (the "License");              #
# you may not use this file except in compliance with the License.             #
# You may obtain a copy of the License at                                      #
#                                                                              #
#     http://www.apache.org/licenses/LICENSE-2.0                               #
#                                                                              #
# Unless required by applicable law or agreed to in writing, software          #
# distributed under the License is distributed on an "AS IS" BASIS,            #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.     #
# See the License for the specific language governing permissions and          #
# limitations under the License.                                               #
#                                                                              #
# ---------------------------------------------------------------------------- #
# ############################################################################ #

# todo Document all lists, dictionaries, etc. in README.md.

from .colored_logger import AnsiColorSetInit, Logger
from .html_colored_logger import HtmlColorSetInitQ, LoggerQ

__authot__ = "Kalynovsky 'Nakama3942' Valentin"
__version__ = "0.2.0"
__email__ = "nakama3942@gmail.com"

==> qt_colored_logger-0.3.0.tar.gz: qt_colored_logger-0.3.0/qt_colored_logger/__init__.py <==
# ##########################   Qt_Colored-logger   ########################### #
# ---------------------------------------------------------------------------- #
#                                                                              #
# Copyright © 2023 Kalynovsky Valentin. All rights reserved.                   #
#                                                                              #
# Licensed under the Apache License, Version 2.0 (the "License");              #
# you may not use this file except in compliance with the License.             #
# You may obtain a copy of the License at                                      #
#                                                                              #
#     http://www.apache.org/licenses/LICENSE-2.0                               #
#                                                                              #
# Unless required by applicable law or agreed to in writing, software          #
# distributed under the License is distributed on an "AS IS" BASIS,            #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.     #
# See the License for the specific language governing permissions and          #
# limitations under the License.                                               #
#                                                                              #
# ---------------------------------------------------------------------------- #
# ############################################################################ #

from .colored_logger import Logger
from .html_colored_logger import LoggerQ

__authot__ = "Kalynovsky 'Nakama3942' Valentin"
__version__ = "0.3.0"
__email__ = "nakama3942@gmail.com"
